@@ -53,7 +53,8 @@ class po2resx:
 
         return bytes(self.templatestore)
 
-    def addcomments(self, inputunit, unit):
+    @staticmethod
+    def addcomments(inputunit, unit):
         comments = []
 
         # Handle #. automatic comments
@@ -76,7 +77,6 @@ class po2resx:
 def convertresx(
     inputfile, outputfile, templatefile, includefuzzy=False, outputthreshold=None
 ):
-
     inputstore = factory.getobject(inputfile)
 
     if templatefile is None:
