@@ -10,6 +10,7 @@ class TestIDML2POCommand(test_convert.TestConvertCommand):
 
     def test_convert(self):
         self.run_command(
-            o="simple.po", i=os.path.join(os.path.dirname(__file__), "test.idml"),
+            o="simple.po",
+            i=os.path.join(os.path.dirname(__file__), "test.idml"),
         )
         assert "THE HEADLINE HERE" in self.read_testfile("simple.po").decode()
