@@ -6,14 +6,16 @@ from translate.storage.test_base import first_translatable, headerless_len
 
 
 class TestPO2CSV:
-    def po2csv(self, posource):
+    @staticmethod
+    def po2csv(posource):
         """helper that converts po source to csv source without requiring files"""
         inputfile = BytesIO(posource.encode())
         inputpo = po.pofile(inputfile)
         convertor = po2csv.po2csv()
         return convertor.convertstore(inputpo)
 
-    def csv2po(self, csvsource, template=None):
+    @staticmethod
+    def csv2po(csvsource, template=None):
         """helper that converts csv source to po source without requiring files"""
         inputfile = BytesIO(csvsource)
         inputcsv = csvl10n.csvfile(inputfile)
@@ -25,7 +27,8 @@ class TestPO2CSV:
         convertor = csv2po.csv2po(templatepo=inputpot)
         return convertor.convertstore(inputcsv)
 
-    def singleelement(self, storage):
+    @staticmethod
+    def singleelement(storage):
         """checks that the pofile contains a single non-header element, and returns it"""
         assert headerless_len(storage.units) == 1
         return first_translatable(storage)
@@ -137,7 +140,41 @@ class TestPO2CSVCommand(test_convert.TestConvertCommand, TestPO2CSV):
 
     convertmodule = po2csv
 
-    def test_help(self, capsys):
-        """tests getting help"""
-        options = test_convert.TestConvertCommand.test_help(self, capsys)
-        options = self.help_check(options, "--columnorder=COLUMNORDER", last=True)
+    expected_options = [
+        "--columnorder=COLUMNORDER",
+    ]
+
+    def test_columnorder(self):
+        pocontent = '#: simple.c\nmsgid "Same"\nmsgstr "Target"\n'
+        self.create_testfile("test.po", pocontent)
+
+        self.run_command("test.po", "test.csv")
+        content = self.open_testfile("test.csv", "r").read()
+        assert (
+            content
+            == """"location","source","target"
+"simple.c","Same","Target"
+"""
+        )
+
+        self.run_command("test.po", "test.csv", columnorder="target,source")
+        content = self.open_testfile("test.csv", "r").read()
+        assert (
+            content
+            == """"target","source"
+"Target","Same"
+"""
+        )
+
+    def test_context(self):
+        pocontent = '#: simple.c\nmsgctxt "Context"\nmsgid "Same"\nmsgstr "Target"\n'
+        self.create_testfile("test.po", pocontent)
+
+        self.run_command("test.po", "test.csv", columnorder="context,source,target")
+        content = self.open_testfile("test.csv", "r").read()
+        assert (
+            content
+            == """"context","source","target"
+"Context","Same","Target"
+"""
+        )
