@@ -1,7 +1,6 @@
 from translate.convert import rc2po, test_convert
 from translate.storage.po import pofile
 
-
 RC_SOURCE = r"""
 #include "other_file.h" // This must be ignored
 
@@ -74,12 +73,14 @@ class TestRC2POCommand(test_convert.TestConvertCommand):
 
     convertmodule = rc2po
     defaultoptions = {"progress": "none"}
-
-    def test_help(self, capsys):
-        """tests getting help"""
-        options = super().test_help(capsys)
-        options = self.help_check(options, "-t TEMPLATE, --template=TEMPLATE")
-        options = self.help_check(options, "-l LANG, --lang=LANG")
+    expected_options = [
+        "-t TEMPLATE, --template=TEMPLATE",
+        "-l LANG, --lang=LANG",
+        "-P, --pot",
+        "--charset=CHARSET",
+        "--sublang=SUBLANG",
+        "--duplicates=DUPLICATESTYLE",
+    ]
 
     def test_convert(self):
         """Tests the conversion to a po file"""
@@ -97,3 +98,46 @@ class TestRC2POCommand(test_convert.TestConvertCommand):
         assert po_result.units[15].getlocations() == [
             "MENU.IDR_MAINFRAME.POPUP.CAPTION"
         ]
+
+    def test_convert_encoding_utf16(self):
+        self.create_testfile("simple.rc", RC_SOURCE.encode("utf-16"))
+        self.run_command(i="simple.rc", o="simple.po", charset="utf-16")
+        po_result = pofile(self.open_testfile("simple.po"))
+        assert len(po_result.units) == 23
+
+    def test_convert_encoding_wrong(self):
+        self.create_testfile("simple.rc", RC_SOURCE.encode("utf-8"))
+        self.run_command(i="simple.rc", o="simple.po", charset="utf-16x")
+        po_result = pofile(self.open_testfile("simple.po"))
+        assert len(po_result.units) == 0
+        self.run_command(i="simple.rc", o="simple.po", charset="utf-16")
+        po_result = pofile(self.open_testfile("simple.po"))
+        assert len(po_result.units) == 0
+
+    def test_convert_encoding_utf8(self):
+        self.create_testfile("simple.rc", RC_SOURCE.encode("utf-8"))
+        self.run_command(i="simple.rc", o="simple.po", charset="utf-8")
+        po_result = pofile(self.open_testfile("simple.po"))
+        assert len(po_result.units) == 23
+
+    def test_menuex(self):
+        source = """
+LANGUAGE LANG_ENGLISH, SUBLANG_ENGLISH_US
+
+IDM_STARTMENU MENUEX
+BEGIN
+    POPUP ""
+    BEGIN
+        MENUITEM "", -1, MFT_SEPARATOR
+        POPUP "&Programs", IDM_PROGRAMS
+        BEGIN
+            MENUITEM "(Empty)", -1, MFT_STRING, MFS_GRAYED
+        END
+        MENUITEM "Sh&ut Down...", IDM_SHUTDOWN, MFT_STRING, MFS_ENABLED
+    END
+END
+"""
+        self.create_testfile("simple.rc", source.encode("utf-8"))
+        self.run_command(i="simple.rc", o="simple.po", charset="utf-8")
+        po_result = pofile(self.open_testfile("simple.po"))
+        assert len(po_result.units) == 5
