@@ -4,7 +4,8 @@ from translate.convert import test_convert, ts2po
 
 
 class TestTS2PO:
-    def ts2po(self, tssource):
+    @staticmethod
+    def ts2po(tssource):
         converter = ts2po.ts2po()
         tsfile = BytesIO(tssource.encode())
         outputpo = converter.convertfile(tsfile)
@@ -141,14 +142,41 @@ new line</translation>
             == "Appears in the Help menu (on Windows and Linux) or the app menu (on macOS)."
         )
 
+    def test_emptycontext(self):
+        """test conversion with a leading empty context"""
+        tssource = """<!DOCTYPE TS><TS>
+<context>
+    <name></name>
+    <message>
+        <source>Message to ignore</source>
+        <translation>Missatge a ignorar</translation>
+    </message>
+</context>
+<context>
+    <name>ValidContext</name>
+    <message>
+        <source>Since we come from abroad, we thought the best thing we could do was to learn the local language and integrate ourselves.</source>
+        <translation>Com que venim de fora vam pensar que el millor que podíem fer era aprendre la llengua d'aquí i integrar-nos.</translation>
+    </message>
+</context>
+</TS>
+"""
+        pofile = self.ts2po(tssource)
+        assert (
+            pofile.units[1].source
+            == "Since we come from abroad, we thought the best thing we could do was to learn the local language and integrate ourselves."
+        )
+        assert (
+            pofile.units[1].target
+            == "Com que venim de fora vam pensar que el millor que podíem fer era aprendre la llengua d'aquí i integrar-nos."
+        )
+
 
 class TestTS2POCommand(test_convert.TestConvertCommand, TestTS2PO):
     """Tests running actual ts2po commands on files"""
 
     convertmodule = ts2po
-
-    def test_help(self, capsys):
-        """tests getting help"""
-        options = test_convert.TestConvertCommand.test_help(self, capsys)
-        options = self.help_check(options, "--duplicates=DUPLICATESTYLE")
-        options = self.help_check(options, "-P, --pot", last=True)
+    expected_options = [
+        "--duplicates=DUPLICATESTYLE",
+        "-P, --pot",
+    ]
