@@ -26,12 +26,20 @@ from translate.storage import po, ts2
 
 
 class ts2po:
-
     def __init__(self, duplicatestyle="msgctxt", pot=False):
         self.duplicatestyle = duplicatestyle
         self.pot = pot
 
-    def convertmessage(self, contextname, messagenum, source, target, disambiguation, msgcomments, transtype):
+    def convertmessage(
+        self,
+        contextname,
+        messagenum,
+        source,
+        target,
+        disambiguation,
+        msgcomments,
+        transtype,
+    ):
         """makes a pounit from the given message"""
         thepo = po.pounit(encoding="UTF-8")
         thepo.addlocation("%s#%d" % (contextname, messagenum))
@@ -55,20 +63,32 @@ class ts2po:
         tsfile = ts2.tsfile(inputfile)
         thetargetfile = po.pofile()
 
-        previouscontext = ''
+        previouscontext = ""
         for inputunit in tsfile.units:
-            contexts = inputunit.getcontext().split('\n')
+            contexts = inputunit.getcontext().split("\n")
+
+            context = contexts[0].strip()
+            # skip the unit if the context is empty
+            if not context:
+                continue
 
-            context = contexts[0]
             if context != previouscontext:
                 previouscontext = context
                 messagenum = 0
 
-            disambiguation = ''
+            disambiguation = ""
             if len(contexts) > 1:
                 disambiguation = contexts[1]
             messagenum += 1
-            thepo = self.convertmessage(context, messagenum, inputunit.source, inputunit.target, disambiguation, inputunit.getnotes(), inputunit._gettype())
+            thepo = self.convertmessage(
+                context,
+                messagenum,
+                inputunit.source,
+                inputunit.target,
+                disambiguation,
+                inputunit.getnotes(),
+                inputunit._gettype(),
+            )
             thetargetfile.addunit(thepo)
 
         thetargetfile.removeduplicates(self.duplicatestyle)
@@ -87,6 +107,7 @@ def convertts(inputfile, outputfile, templates, pot=False, duplicatestyle="msgct
 
 def main(argv=None):
     from translate.convert import convert
+
     formats = {"ts": ("po", convertts)}
     parser = convert.ConvertOptionParser(formats, usepots=True, description=__doc__)
     parser.add_duplicates_option()
@@ -94,5 +115,5 @@ def main(argv=None):
     parser.run(argv)
 
 
-if __name__ == '__main__':
+if __name__ == "__main__":
     main()
