@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 #
 # Copyright 2010, 2016 Zuza Software Foundation
 #
@@ -19,9 +18,10 @@
 
 """This module represents the Marathi language.
 
-.. seealso:: http://en.wikipedia.org/wiki/Marathi_language
+.. seealso:: :wp:`Marathi_language`
 """
 
+
 from translate.lang import common
 
 
@@ -29,5 +29,5 @@ class mr(common.Common):
     """This class represents Marathi."""
 
     ignoretests = {
-        'all': ["simplecaps", "startcaps"],
+        "all": ["simplecaps", "startcaps"],
     }
