@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 #
 # Copyright 2009 Zuza Software Foundation
 #
@@ -19,17 +18,20 @@
 
 """This module represents the the Swedish language.
 
-.. seealso:: http://en.wikipedia.org/wiki/Swedish_language
+.. seealso:: :wp:`Swedish_language`
 """
 
+
 from translate.lang import common
 
 
 class sv(common.Common):
     """This class represents Swedish."""
 
-    validaccel = (u"abcdefghijklmnopqrstuvwxyz"
-                  u"ABCDEFGHIJKLMNOPQRSTUVWXYZ"
-                  u"1234567890"
-                  u"åäö"
-                  u"ÅÄÖ")
+    validaccel = (
+        "abcdefghijklmnopqrstuvwxyz"
+        "ABCDEFGHIJKLMNOPQRSTUVWXYZ"
+        "1234567890"
+        "åäö"
+        "ÅÄÖ"
+    )
