@@ -91,7 +91,6 @@ from lxml import etree
 from translate.misc import quote
 from translate.storage import base
 
-
 labelsuffixes = (".label", ".title")
 """Label suffixes: entries with this suffix are able to be comibed with accesskeys
 found in in entries ending with :attr:`.accesskeysuffixes`"""
@@ -206,9 +205,8 @@ def removeinvalidamps(name, value):
         if amppos != -1:
             amppos += 1
             semipos = value.find(";", amppos)
-            if semipos != -1:
-                if is_valid_entity_name(value[amppos:semipos]):
-                    continue
+            if semipos != -1 and is_valid_entity_name(value[amppos:semipos]):
+                continue
             invalid_amps.append(amppos - 1)
     if len(invalid_amps) > 0:
         warnings.warn("invalid ampersands in dtd entity %s" % (name))
@@ -260,8 +258,7 @@ class dtdunit(base.TranslationUnit):
         """gets the unquoted target string"""
         if self.android:
             return unquotefromandroid(self.definition)
-        else:
-            return unquotefromdtd(self.definition)
+        return unquotefromdtd(self.definition)
 
     @target.setter
     def target(self, target):
@@ -567,7 +564,7 @@ class dtdfile(base.TranslationStore):
                     break
                 if lines[end].find(b"<!ENTITY") > -1:
                     foundentity = True
-                if foundentity and re.match(br"[\"']\s*>", lines[end]):
+                if foundentity and re.match(rb"[\"']\s*>", lines[end]):
                     end += 1
                     break
                 end += 1
