@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 #
 # Copyright 2009 Zuza Software Foundation
 #
@@ -37,19 +36,12 @@ Encoding
     encoded files use the .utf8 extension while system encoded files use
     the .tab extension.
 """
-from __future__ import unicode_literals
 
+import csv
 import locale
-import six
-if six.PY2:
-    from backports import csv
-else:
-    import csv
 
-from translate.misc.deprecation import deprecated
 from translate.storage import base
 
-
 OMEGAT_FIELDNAMES = ["source", "target", "comment"]
 """Field names for an OmegaT glossary unit"""
 
@@ -67,7 +59,6 @@ class OmegaTDialect(csv.Dialect):
 csv.register_dialect("omegat", OmegaTDialect)
 
 
-@six.python_2_unicode_compatible
 class OmegaTUnit(base.TranslationUnit):
     """An OmegaT glossary unit"""
 
@@ -75,7 +66,7 @@ class OmegaTUnit(base.TranslationUnit):
         self._dict = {}
         if source:
             self.source = source
-        super(OmegaTUnit, self).__init__(source)
+        super().__init__(source)
 
     def getdict(self):
         """Get the dictionary of values for a OmegaT line"""
@@ -89,6 +80,7 @@ class OmegaTUnit(base.TranslationUnit):
         """
         # TODO First check that the values are OK
         self._dict = newdict
+
     dict = property(getdict, setdict)
 
     def _get_field(self, key):
@@ -106,55 +98,46 @@ class OmegaTUnit(base.TranslationUnit):
             self._dict[key] = newvalue
 
     def getnotes(self, origin=None):
-        return self._get_field('comment')
+        return self._get_field("comment")
 
     def addnote(self, text, origin=None, position="append"):
-        currentnote = self._get_field('comment')
-        if position == "append" and currentnote is not None and currentnote != u'':
-            self._set_field('comment', currentnote + '\n' + text)
+        currentnote = self._get_field("comment")
+        if position == "append" and currentnote is not None and currentnote != "":
+            self._set_field("comment", currentnote + "\n" + text)
         else:
-            self._set_field('comment', text)
+            self._set_field("comment", text)
 
     def removenotes(self, origin=None):
-        self._set_field('comment', u'')
+        self._set_field("comment", "")
 
     @property
     def source(self):
-        return self._get_field('source')
+        return self._get_field("source")
 
     @source.setter
     def source(self, source):
         self._rich_source = None
-        self._set_field('source', source)
-
-    # Deprecated on 2.3.1
-    @deprecated("Use `source` property instead")
-    def getsource(self):
-        return self.source
+        self._set_field("source", source)
 
     @property
     def target(self):
-        return self._get_field('target')
+        return self._get_field("target")
 
     @target.setter
     def target(self, target):
         self._rich_target = None
-        self._set_field('target', target)
-
-    # Deprecated on 2.3.1
-    @deprecated("Use `target` property instead")
-    def gettarget(self):
-        return self.target
+        self._set_field("target", target)
 
     def settargetlang(self, newlang):
-        self._dict['target-lang'] = newlang
+        self._dict["target-lang"] = newlang
+
     targetlang = property(None, settargetlang)
 
     def __str__(self):
         return str(self._dict)
 
     def istranslated(self):
-        return bool(self._dict.get('target', None))
+        return bool(self._dict.get("target", None))
 
 
 class OmegaTFile(base.TranslationStore):
@@ -166,20 +149,19 @@ class OmegaTFile(base.TranslationStore):
     UnitClass = OmegaTUnit
 
     def __init__(self, inputfile=None, **kwargs):
-        """Construct an OmegaT glossary, optionally reading in from inputfile.
-        """
-        super(OmegaTFile, self).__init__(**kwargs)
-        self.filename = ''
-        self.extension = ''
+        """Construct an OmegaT glossary, optionally reading in from inputfile."""
+        super().__init__(**kwargs)
+        self.filename = ""
+        self.extension = ""
         if inputfile is not None:
             self.parse(inputfile)
 
     def parse(self, input):
         """parsese the given file or file source string"""
-        if hasattr(input, 'name'):
+        if hasattr(input, "name"):
             self.filename = input.name
-        elif not getattr(self, 'filename', ''):
-            self.filename = ''
+        elif not getattr(self, "filename", ""):
+            self.filename = ""
         if hasattr(input, "read"):
             tmsrc = input.read()
             input.close()
@@ -187,9 +169,12 @@ class OmegaTFile(base.TranslationStore):
         try:
             input = input.decode(self.encoding)
         except Exception:
-            raise ValueError("OmegaT files are either UTF-8 encoded or use the default system encoding")
-        lines = csv.DictReader(input.split("\n"), fieldnames=OMEGAT_FIELDNAMES,
-                               dialect="omegat")
+            raise ValueError(
+                "OmegaT files are either UTF-8 encoded or use the default system encoding"
+            )
+        lines = csv.DictReader(
+            input.split("\n"), fieldnames=OMEGAT_FIELDNAMES, dialect="omegat"
+        )
         for line in lines:
             newunit = OmegaTUnit()
             newunit.dict = line
