@@ -3,13 +3,12 @@ import os
 from translate.storage import base, po, xliff
 from translate.tools import podebug
 
-
 PO_DOC = """
 msgid "This is a %s test, hooray."
 msgstr ""
 """
 
-XLIFF_DOC = """<?xml version='1.0' encoding='utf-8'?>
+XLIFF_DOC = """<?xml version="1.0" encoding="utf-8"?>
 <xliff xmlns="urn:oasis:names:tc:xliff:document:1.1" version="1.1">
   <file original="NoName" source-language="en" datatype="plaintext">
     <body>
@@ -34,7 +33,8 @@ class TestPODebug:
         unit = base.TranslationUnit("default:LTR")
         assert self.debug.ignore_gtk(unit)
 
-    def test_keep_target(self):
+    @staticmethod
+    def test_keep_target():
         """Test that we use the target for rewriting if it exists."""
         unit = base.TranslationUnit("blie")
 
@@ -70,22 +70,26 @@ class TestPODebug:
         """Test the unicode rewrite function"""
         assert str(self.debug.rewrite_unicode("Test")) == "Ŧḗşŧ"
 
-    def test_rewrite_unicode_preserves_at_placeholders(self):
+    @staticmethod
+    def test_rewrite_unicode_preserves_at_placeholders():
         """Test the unicode rewrite function"""
         debug = podebug.podebug(preserveplaceholders=True)
         assert str(debug.rewrite_unicode("@@ph@@Test @@ph@@")) == "@@ph@@Ŧḗşŧ @@ph@@"
 
-    def test_rewrite_unicode_preserves_single_brace_placeholders(self):
+    @staticmethod
+    def test_rewrite_unicode_preserves_single_brace_placeholders():
         """Test the unicode rewrite function"""
         debug = podebug.podebug(preserveplaceholders=True)
         assert str(debug.rewrite_unicode("{ph}Test {ph}")) == "{ph}Ŧḗşŧ {ph}"
 
-    def test_rewrite_unicode_preserves_double_brace_placeholders(self):
+    @staticmethod
+    def test_rewrite_unicode_preserves_double_brace_placeholders():
         """Test the unicode rewrite function"""
         debug = podebug.podebug(preserveplaceholders=True)
         assert str(debug.rewrite_unicode("{{ph}}Test {{ph}}")) == "{{ph}}Ŧḗşŧ {{ph}}"
 
-    def test_rewrite_unicode_preserves_html(self):
+    @staticmethod
+    def test_rewrite_unicode_preserves_html():
         """Test the unicode rewrite function"""
         debug = podebug.podebug(preserveplaceholders=True)
         assert (
@@ -93,7 +97,8 @@ class TestPODebug:
             == "<style0>Ŧḗşŧ</style0>"
         )
 
-    def test_rewrite_unicode_preserves_multiple_styles_of_placeholder(self):
+    @staticmethod
+    def test_rewrite_unicode_preserves_multiple_styles_of_placeholder():
         """Test the unicode rewrite function"""
         debug = podebug.podebug(preserveplaceholders=True)
         assert (
@@ -110,26 +115,30 @@ class TestPODebug:
         assert str(self.debug.rewrite_flipped(" ")) == "\u202e "
         assert str(self.debug.rewrite_flipped("©")) == "\u202e©"
 
-    def test_rewrite_flipped_preserves_at_placeholders(self):
+    @staticmethod
+    def test_rewrite_flipped_preserves_at_placeholders():
         """Test the unicode rewrite function"""
         debug = podebug.podebug(preserveplaceholders=True)
         assert (
             str(debug.rewrite_flipped("@@ph@@Test @@ph@@")) == "\u202e@@ph@@⊥ǝsʇ @@ph@@"
         )
 
-    def test_rewrite_flipped_preserves_single_brace_placeholders(self):
+    @staticmethod
+    def test_rewrite_flipped_preserves_single_brace_placeholders():
         """Test the unicode rewrite function"""
         debug = podebug.podebug(preserveplaceholders=True)
         assert str(debug.rewrite_flipped("{ph}Test {ph}")) == "\u202e{ph}⊥ǝsʇ {ph}"
 
-    def test_rewrite_flipped_preserves_double_brace_placeholders(self):
+    @staticmethod
+    def test_rewrite_flipped_preserves_double_brace_placeholders():
         """Test the unicode rewrite function"""
         debug = podebug.podebug(preserveplaceholders=True)
         assert (
             str(debug.rewrite_flipped("{{ph}}Test {{ph}}")) == "\u202e{{ph}}⊥ǝsʇ {{ph}}"
         )
 
-    def test_rewrite_flipped_preserves_html(self):
+    @staticmethod
+    def test_rewrite_flipped_preserves_html():
         """Test the unicode rewrite function"""
         debug = podebug.podebug(preserveplaceholders=True)
         assert (
@@ -137,7 +146,8 @@ class TestPODebug:
             == "\u202e<style0>⊥ǝsʇ </style0>"
         )
 
-    def test_rewrite_flipped_multiple_styles_of_placeholder(self):
+    @staticmethod
+    def test_rewrite_flipped_multiple_styles_of_placeholder():
         """Test the unicode rewrite function"""
         debug = podebug.podebug(preserveplaceholders=True)
         assert (
@@ -145,6 +155,51 @@ class TestPODebug:
             == "\u202e<b>{{ph}}⊥ǝsʇ{ph}@@ph@@⊥ǝsʇ</b>"
         )
 
+    def test_rewrite_classified(self):
+        """Test the unicode rewrite function"""
+        assert str(self.debug.rewrite_classified("Test")) == "▮▮▮▮"
+        # alternative with reversed string and no RTL override:
+        # assert unicode(self.debug.rewrite_classified("Test")) == "ʇsǝ⊥"
+        # Chars < ! and > z are returned as is
+        assert str(self.debug.rewrite_classified(" ")) == " "
+        assert str(self.debug.rewrite_classified("©")) == "©"
+
+    @staticmethod
+    def test_rewrite_classified_preserves_at_placeholders():
+        """Test the unicode rewrite function"""
+        debug = podebug.podebug(preserveplaceholders=True)
+        assert str(debug.rewrite_classified("@@ph@@Test @@ph@@")) == "@@ph@@▮▮▮▮ @@ph@@"
+
+    @staticmethod
+    def test_rewrite_classified_preserves_single_brace_placeholders():
+        """Test the unicode rewrite function"""
+        debug = podebug.podebug(preserveplaceholders=True)
+        assert str(debug.rewrite_classified("{ph}Test {ph}")) == "{ph}▮▮▮▮ {ph}"
+
+    @staticmethod
+    def test_rewrite_classified_preserves_double_brace_placeholders():
+        """Test the unicode rewrite function"""
+        debug = podebug.podebug(preserveplaceholders=True)
+        assert str(debug.rewrite_classified("{{ph}}Test {{ph}}")) == "{{ph}}▮▮▮▮ {{ph}}"
+
+    @staticmethod
+    def test_rewrite_classified_preserves_html():
+        """Test the unicode rewrite function"""
+        debug = podebug.podebug(preserveplaceholders=True)
+        assert (
+            str(debug.rewrite_classified("<style0>Test </style0>"))
+            == "<style0>▮▮▮▮ </style0>"
+        )
+
+    @staticmethod
+    def test_rewrite_classified_multiple_styles_of_placeholder():
+        """Test the unicode rewrite function"""
+        debug = podebug.podebug(preserveplaceholders=True)
+        assert (
+            str(debug.rewrite_classified("<b>{{ph}}Test{ph}@@ph@@Test</b>"))
+            == "<b>{{ph}}▮▮▮▮{ph}@@ph@@▮▮▮▮</b>"
+        )
+
     def test_rewrite_chef(self):
         """Test the chef rewrite function
 
@@ -184,7 +239,8 @@ class TestPODebug:
         print(bytes(xliff_out))
         assert out_unit.target == "xxx%sxxx" % (in_unit.source)
 
-    def test_hash(self):
+    @staticmethod
+    def test_hash():
         po_docs = (
             """
 msgid "Test msgid 1"
