@@ -1,4 +1,3 @@
-import warnings
 from io import BytesIO
 
 from pytest import mark
@@ -18,13 +17,8 @@ class TestPretranslate:
         </file>
 </xliff>"""
 
-    def setup_method(self, method):
-        warnings.resetwarnings()
-
-    def teardown_method(self, method):
-        warnings.resetwarnings()
-
-    def pretranslatepo(self, input_source, template_source=None):
+    @staticmethod
+    def pretranslatepo(input_source, template_source=None):
         """helper that converts strings to po source without requiring files"""
         input_file = BytesIO(input_source.encode())
         if template_source:
@@ -37,7 +31,8 @@ class TestPretranslate:
         output_file.seek(0)
         return po.pofile(output_file.read())
 
-    def pretranslatexliff(self, input_source, template_source=None):
+    @staticmethod
+    def pretranslatexliff(input_source, template_source=None):
         """helper that converts strings to po source without requiring files"""
         input_file = BytesIO(input_source)
         if template_source:
@@ -50,7 +45,8 @@ class TestPretranslate:
         output_file.seek(0)
         return xliff.xlifffile(output_file.read())
 
-    def singleunit(self, pofile):
+    @staticmethod
+    def singleunit(pofile):
         """
         checks that the pofile contains a single non-header unit, and
         returns it
@@ -366,13 +362,9 @@ class TestPretranslateCommand(test_convert.TestConvertCommand, TestPretranslate)
     """Tests running actual pretranslate commands on files"""
 
     convertmodule = pretranslate
-
-    def test_help(self, capsys):
-        """tests getting help"""
-        options = test_convert.TestConvertCommand.test_help(self, capsys)
-        options = self.help_check(options, "-t TEMPLATE, --template=TEMPLATE")
-        options = self.help_check(options, "--tm")
-        options = self.help_check(
-            options, "-s MIN_SIMILARITY, --similarity=MIN_SIMILARITY"
-        )
-        options = self.help_check(options, "--nofuzzymatching", last=True)
+    expected_options = [
+        "-t TEMPLATE, --template=TEMPLATE",
+        "--tm",
+        "-s MIN_SIMILARITY, --similarity=MIN_SIMILARITY",
+        "--nofuzzymatching",
+    ]
